@@ -14,6 +14,6 @@ def help():
     print(
         "Please go to https://pypi.org/project/canalyst-candas/#description for installation help"
     )
-    print("For support, please contact jed.gore@canalyst.com")
+    print("For support, please contact candas@canalyst.com")
     print("For an API KEY please go to https://app.canalyst.com/u/settings/api-tokens")
     print("For an Excel model download:get_excel_model(ticker, config)")
