@@ -336,7 +336,7 @@ class ModelSet:
         col_for_labels="time_series_name",
         time_series_name="MO_RIS_REV",
         tree=True,
-        notebook=False,
+        notebook=True,
     ):
         """
         Return a ModelMap for a given time series name.
@@ -352,7 +352,7 @@ class ModelSet:
             String of time_series_name to be used for the ROOT node of the tree
         tree : boolean, default True
             Very complex trees might be rendered better with tree=False
-        notebook : boolean, default False
+        notebook : boolean, default True
             Launches tree in a separate browser window (False) or in the notebook (True)
 
         Returns
